@@ -15,20 +15,14 @@ class Extractor(object):
     def __init__(self, **kwargs):
         if 'pdf' in kwargs:
             self.data = kwargs['pdf']
+        if "keepBrTags" in kwargs:
+            self.keepBrTags = kwargs['keepBrTags']
         else:
-            raise Exception('No pdf provided')
-        if "language" in kwargs:
-            self.language = kwargs['language']
+            self.keepBrTags = 0
+        if "getPermission" in kwargs:
+            self.getPermission = kwargs['getPermission']
         else:
-            self.language = "en"
-        if "options" in kwargs:
-            self.options = kwargs['options']
-        else:
-            self.options = ""
-        if "debug" in kwargs:
-            self.debug = kwargs['debug']
-        else:
-            self.debug = 0
+            self.getPermission = 0 
         try:
             # make it thread-safe
             if threading.activeCount() > 1:
@@ -36,12 +30,14 @@ class Extractor(object):
                     attachThreadToJVM()
             lock.acquire()
 
-            self.extractor = JClass("com.java.app.PDFExtract")()
+            self.extractor = JClass("pdfextract.PDFExtract")()
 
         finally:
             lock.release()
 
-        self.reader = ByteArrayInputStream(self.data)
+    def setData(self,data):
+        self.data = data
 
     def getHTML(self):
-        return str(self.extractor.Extract(self.reader, JString(self.language), JString(self.options), self.debug).toString())
+        self.reader = ByteArrayInputStream(self.data)
+        return str(self.extractor.Extract(self.reader, self.keepBrTags, self.getPermission).toString())
